// Copyright Oleg Maximenko 2014.
// Distributed under the Boost Software License, Version 1.0.
// (See accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
//
// See http://github.com/svgpp/svgpp for library home page.

#pragma once

#include <svgpp/utility/boost_parameter_fixed.hpp>
#include <svgpp/template_parameters.hpp>

namespace svgpp
{

template<class ValueType, SVGPP_TEMPLATE_ARGS_DEF>
struct value_parser;

}
